/*
  MotorL293.h - Motor Library to use with L293 chip.
  Created by Martin Nawrath and Andreas Muxel, 2008.
  http://interface.khm.de
  Released into the public domain.
*/
#include "Arduino.h"
#include "MotorL293.h"

// for setting registers
#ifndef cbi
#define cbi(sfr, bit) (_SFR_BYTE(sfr) &= ~_BV(bit))
#endif
#ifndef sbi
#define sbi(sfr, bit) (_SFR_BYTE(sfr) |= _BV(bit))
#endif

// constructor
MotorL293::MotorL293(){};
// attach
void MotorL293::attach(int pin1, int pin2, int pinPWM)
{
	// Timer 1 prescaler to 1
	cbi(TCCR1B, CS12);
	cbi(TCCR1B, CS11);
	sbi(TCCR1B, CS10);
	// motor pins
	motorPin1 = pin1;
	motorPin2 = pin2;
	pinMode(motorPin1, OUTPUT);
	pinMode(motorPin2, OUTPUT);
	// PWM pins
	pwmPin = pinPWM;
	pinMode(pwmPin, OUTPUT);
}
// set direction
void MotorL293::setDirection(int direction){
	// turn left
	if(direction == 0){
		digitalWrite(motorPin1,HIGH);
		digitalWrite(motorPin2,LOW);
	}else{
		digitalWrite(motorPin1,LOW);
		digitalWrite(motorPin2,HIGH);
	}
}
// set power
void MotorL293::setPower(int power){
	//
	// set pwms
	//
	// check which pin
	if(pwmPin ==  9){
		// connect pwm to pin on timer 1, channel A
		sbi(TCCR1A, COM1A1);
		// set pwm duty
		OCR1A = power;
	}else{
		// connect pwm to pin on timer 1, channel B
		sbi(TCCR1A, COM1B1);
		// set pwm duty
		OCR1B = power;
	}
}
